@@ -33,6 +33,12 @@ check( <<'EOF', qw(-p s=b) );
 11
 EOF
 
+check( <<'EOF', qw(-l) );
+a
+b
+c
+EOF
+
 check( <<'EOF', qw(-p s=b --noskipempty) );
 #!/bin/xxx
 # s
@@ -349,10 +355,39 @@ check( <<'EOF', '-p', 'a,[bc]' );
 10 11 12
 EOF
 
+check( <<'EOF', '--sub-abs', '-p', 'x=abs(a-5)' );
+#!/bin/xxx
+# x
+4
+1
+2
+5
+EOF
+
 check( 'ERROR', '-p', 'a,+[bc]' );
 
 check( 'ERROR', '-p', '+.' );
 
+check( <<'EOF', qw(--BEGIN x=5 --END), 'print 100', qw(-p s=a+x), {language => 'AWK'} );
+#!/bin/xxx
+# s
+6
+9
+12
+15
+100
+EOF
+
+check( <<'EOF', qw(--BEGIN $x=5 --END), 'say 100', qw(-p s=a+$x), {language => 'perl'} );
+#!/bin/xxx
+# s
+6
+9
+12
+15
+100
+EOF
+
 check( <<'EOF', qw(-p d=rel(a) -p s=sum(a) -p pa=prev(a) -p b -p c -p pdb=latestdefined(b) --noskipempty));
 #!/bin/xxx
 # d s pa b c pdb
